==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebRippleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRippleDescription } from "./WebRippleDescription";
/**
 * @hidden
 */
var WebRippleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRippleDescriptionMetadata, _super);
    function WebRippleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRippleDescriptionMetadata.b = function (a) {
        if (WebRippleDescriptionMetadata.a == null) {
            WebRippleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRippleDescriptionMetadata.c(WebRippleDescriptionMetadata.a);
        }
        if (a.j(WebRippleDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRippleDescriptionMetadata.a);
    };
    WebRippleDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Ripple");
        a.item("__tagNameWC", "String:igc-ripple");
    };
    WebRippleDescriptionMetadata.d = function (a) {
        WebRippleDescriptionMetadata.b(a);
        a.aa("WebRipple", function () { return new WebRippleDescription(); });
        a.z("WebRipple", WebRippleDescriptionMetadata.a);
    };
    WebRippleDescriptionMetadata.$t = markType(WebRippleDescriptionMetadata, 'WebRippleDescriptionMetadata');
    WebRippleDescriptionMetadata.a = null;
    return WebRippleDescriptionMetadata;
}(Base));
export { WebRippleDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebRippleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRippleDescription } from "./WebRippleDescription";
/**
 * @hidden
 */
var WebRippleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRippleDescriptionMetadata, _super);
    function WebRippleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRippleDescriptionMetadata.b = function (a) {
        if (WebRippleDescriptionMetadata.a == null) {
            WebRippleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRippleDescriptionMetadata.c(WebRippleDescriptionMetadata.a);
        }
        if (a.k(WebRippleDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRippleDescriptionMetadata.a);
    };
    WebRippleDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Ripple");
        a.item("__tagNameWC", "String:igc-ripple");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebRippleDescriptionMetadata.d = function (a) {
        WebRippleDescriptionMetadata.b(a);
        a.ac("WebRipple", function () { return new WebRippleDescription(); });
        a.ab("WebRipple", WebRippleDescriptionMetadata.a);
    };
    WebRippleDescriptionMetadata.$t = markType(WebRippleDescriptionMetadata, 'WebRippleDescriptionMetadata');
    WebRippleDescriptionMetadata.a = null;
    return WebRippleDescriptionMetadata;
}(Base));
export { WebRippleDescriptionMetadata };
